@@ -17,7 +17,7 @@ def upsacale(image,cvdnn_path):
 
 # Create an SR object
     sr = dnn_superres.DnnSuperResImpl_create()
-    sr.readModel(cvdnn_path)
+    sr.readModel(cvdnn_path,device='cuda:0')
     sr.setModel("fsrcnn", 3)
     result = sr.upsample(image)
     return result
@@ -39,7 +39,7 @@ def inference(img_path,ocr,cvdnn_path):
                 regex = '^[+-]?[0-9]+\.[0-9]$'
                 for i in range(0,len(txts)):# most repeating txts
                     if(re.search(regex, txts[i])): 
-                            if float(txts[i]) > 20.0 or float(txts[i]) <= 15.0:
+                            if float(txts[i]) < 20.0 and float(txts[i]) >= 15.0:
                                 txts.pop(i)
                                 scores.pop(i)
                             else:
@@ -58,7 +58,7 @@ def inference(img_path,ocr,cvdnn_path):
                 case=np.argmax(scores)
                 scores=[scores[case]]
                 txts=[txts[case]]
-            if(re.search(regex, txts[0])):
+            if(re.search(regex, txts[0]) and txts[0]<20.0 and txts[0]>15.0):
                     return str(txts[0]),float(scores[0])
             else:
                     return "999",float(0.0)
